import time

from vkbottle.framework.framework.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database, LastMessage, SlouMo
from idm_lp.rules import SlouMoRule
from idm_lp.utils import edit_message

user = Blueprint(
    name='sloumo_blueprint'
)


@user.on.chat_message(SlouMoRule())
async def sloumo_proc_wrapper(message: Message):
    if message.from_id < 0:
        return

    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i

    if (
            message.from_id not in db.sloumo[index].white_list and
            db.sloumo[index].last_message.date + db.sloumo[index].time >= time.time() and
            db.sloumo[index].last_message.from_id == message.from_id
    ):
        await message(f"!warn @id{message.from_id}\n{db.sloumo[index].warn_message}")

    db.sloumo[index].last_message = LastMessage(
        date=message.date,
        from_id=message.from_id
    )
    db.save()


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> +слоумо <delay_time:int>\n<warn_text>")
@user.on.message_handler(FromMe(), text="<prefix:service_prefix> +слоумо <delay_time:int>")
@user.on.message_handler(FromMe(), text="<prefix:service_prefix> +слоумо")
@logger_decorator
async def enable_sloumo_wrapper(
        message: Message,
        delay_time: int = 10,
        warn_text: str = "Нарушение слоумо-режима",
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is not None:
        db.sloumo.pop(index)
    db.save()

    db.sloumo.append(SlouMo(
        chat_id=message.chat_id,
        last_message=dict(from_id=0, date=0),
        white_list=[
            message.from_id,
            *[
                item.member_id
                for item in (await message.api.messages.get_conversation_members(peer_id=message.peer_id)).items
                if item.is_admin and item.member_id > 0
            ]
        ],
        warn_message=warn_text,
        time=delay_time
    ))
    await edit_message(
        message,
        f"✅ Слоумо режим в этой беседе установлен:\n"
        f"⏱ Задержка {delay_time} сек.\n"
        f"⚠ Текст предупреждения: {warn_text}"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> -слоумо")
@logger_decorator
async def disable_sloumo_wrapper(
        message: Message,
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is not None:
        db.sloumo.pop(index)
    db.save()
    await edit_message(
        message,
        f"✅ Слоумо режим в этой беседе был отключен\n"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> слоумо")
@logger_decorator
async def show_sloumo_wrapper(
        message: Message,
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is None:
        await edit_message(message, 'Слоумо режим в этой беседе не настроен')
        return

    white_list = ""
    users = (await message.api.users.get(user_ids=db.sloumo[index].white_list))
    for _user in users:
        white_list += f"[id{_user.id}|{_user.first_name} {_user.last_name}]\n"

    await edit_message(
        message,
        f"✅ Слоумо режим в этой беседе установлен:\n"
        f"⏱ Задержка {db.sloumo[index].time} сек.\n"
        f"⚠ Текст предупреждения: {db.sloumo[index].warn_message}\n"
        f"Белый список: {white_list}"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> слоумо +белый список [id<user_id:int>|<foo>")
@logger_decorator
async def show_sloumo_wrapper(
        message: Message,
        user_id: int,
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is None:
        await edit_message(message, 'Слоумо режим в этой беседе не настроен')
        return

    db.sloumo[index].white_list.append(user_id)
    db.save()
    white_list = ""
    users = (await message.api.users.get(user_ids=db.sloumo[index].white_list))
    for _user in users:
        white_list += f"[id{_user.id}|{_user.first_name} {_user.last_name}]\n"

    await edit_message(
        message,
        f"✅ Пользователь добавлен в белый список\n"
        f"Белый список: {white_list}"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> слоумо -белый список [id<user_id:int>|<foo>")
@logger_decorator
async def show_sloumo_wrapper(
        message: Message,
        user_id: int,
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is None:
        await edit_message(message, 'Слоумо режим в этой беседе не настроен')
        return

    if user_id in db.sloumo[index].white_list:
        db.sloumo[index].white_list.remove(user_id)
        db.save()
    white_list = ""
    users = (await message.api.users.get(user_ids=db.sloumo[index].white_list))
    for _user in users:
        white_list += f"[id{_user.id}|{_user.first_name} {_user.last_name}]\n"

    await edit_message(
        message,
        f"✅ Пользователь удален из белого списка\n"
        f"Белый список: {white_list}"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> слоумо время <delay_time:int>")
@logger_decorator
async def show_sloumo_wrapper(
        message: Message,
        delay_time: int,
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is None:
        await edit_message(message, 'Слоумо режим в этой беседе не настроен')
        return
    db.sloumo[index].time = delay_time
    db.save()
    await edit_message(
        message,
        f"✅ Время слоумо режима изменено на {delay_time}"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> слоумо текст <text>")
@logger_decorator
async def show_sloumo_wrapper(
        message: Message,
        text: str,
        **kwargs
):
    db = Database.get_current()
    index = None
    for i in range(len(db.sloumo)):
        if db.sloumo[i].chat_id == message.chat_id:
            index = i
    if index is None:
        await edit_message(message, 'Слоумо режим в этой беседе не настроен')
        return
    db.sloumo[index].warn_message = text
    db.save()
    await edit_message(
        message,
        f"✅ Текст предупреждени я изменен на \"{text}\""
    )



import os

from idm_lp.database import Database

def setup():
    try:
        os.mkdir('idm_lp')
    except:
        pass
    
    tokens = []
    while len(tokens) != 3:
        token = input("Введите токен VK (85 символов) >> ")
        if len(token) != 85:
            print("Не верный токен")
            continue
        tokens.append(token)

    with open(os.path.join('idm_lp', 'config.json'), 'w', encoding='utf-8') as file:
        db = Database()
        db.tokens.extend(tokens)
        file.write(db.json())

    with open(os.path.join('idm_lp', 'lp_dc_config.json'), 'w', encoding='utf-8') as file:
        file.write('{"app_secret": "public", "app_id": 0}')

    print("Конфиг записан")





from typing import Optional

from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import RolePlayCommand, Database, GenEnum
from idm_lp.utils import edit_message

user = Blueprint(
    name='role_play_commands_blueprint'
)


async def get_role_play_message(
        message: Message,
        role_play_command: RolePlayCommand,
        user_id: Optional[int] = None,
        call_all: bool = False
) -> str:
    called_user = (await message.api.users.get(fields=["sex"]))[0]

    pattern = role_play_command.formatter_woman if called_user.sex == 1 else role_play_command.formatter_man

    first_user = f"[id{called_user.id}|{called_user.first_name} {called_user.last_name}]"
    if call_all:
        return pattern.format(
            first_user=first_user,
            second_user=role_play_command.all_ending
        )

    second_user = (await message.api.users.get(user_ids=user_id, name_case=role_play_command.gen))[0]
    last_user = f"[id{second_user.id}|{second_user.first_name} {second_user.last_name}]"
    return pattern.format(
        first_user=first_user,
        second_user=last_user
    )


all_role_play_cmd = [
    "<service_prefix:service_prefix> <role_play_command:role_play_command> всех",
    "<service_prefix:service_prefix> <role_play_command:role_play_command> всем",
]


@user.on.message_handler(FromMe(), text="<service_prefix:service_prefix> рп")
async def show_rp_commands(message: Message, **kwargs):
    db = Database.get_current()
    text = "📃 Доступные РП-команды:\n"
    index = 1
    for rp_cmd in db.role_play_commands:
        text += f"{index}. {rp_cmd.name}\n"
        index += 1
    await edit_message(
        message,
        text
    )


@user.on.message_handler(FromMe(), text=all_role_play_cmd)
@logger_decorator
async def role_play_command_wrapper(
        message: Message,
        role_play_command: RolePlayCommand,
        **kwargs
):
    await edit_message(
        message,
        await get_role_play_message(
            message,
            role_play_command,
            call_all=True
        )
    )


user_id_cmd = "<service_prefix:service_prefix> <role_play_command:role_play_command> [id<user_id:int>|<name>]"


@user.on.message_handler(FromMe(), text=user_id_cmd)
@logger_decorator
async def role_play_command_wrapper(
        message: Message,
        role_play_command: RolePlayCommand,
        user_id: int,
        **kwargs
):
    await edit_message(
        message,
        await get_role_play_message(
            message,
            role_play_command,
            user_id=user_id
        )
    )


no_user_id_cmd = "<service_prefix:service_prefix> <role_play_command:role_play_command>"


@user.on.message_handler(FromMe(), text=no_user_id_cmd)
@logger_decorator
async def role_play_command_wrapper(
        message: Message,
        role_play_command: RolePlayCommand,
        **kwargs
):
    user_id = None
    if message.reply_message:
        user_id = message.reply_message.from_id
    if message.fwd_messages:
        user_id = message.fwd_messages[0].from_id

    if not user_id:
        return

    if user_id < 0:
        return

    await edit_message(
        message,
        await get_role_play_message(
            message,
            role_play_command,
            user_id=user_id
        )
    )

mrp_create_text = [
    "<service_prefix:service_prefix> +мрп <name> <gen>\n<formatter_man>\n<formatter_woman>\n<all_ending>",
    "<service_prefix:service_prefix> +мрп <name>\n<formatter_man>\n<formatter_woman>\n<all_ending>"
]


@user.on.message_handler(FromMe(), text=mrp_create_text)
@logger_decorator
async def role_play_command_create_wrapper(
        message: Message,
        name: str,
        formatter_man: str,
        formatter_woman: str,
        all_ending: str,
        gen: str = "acc",
        **kwargs
):
    db = Database.get_current()
    try:
        gen = GenEnum(gen)
    except:
        await edit_message(
            message,
            f"⚠ Не верный падеж. Используйте следующие обозначения:\n"
            "именительный – nom\nродительный – gen\nдательный – dat\nвинительный – acc\nтворительный – ins\nпредложный – abl"
        )
        return
    
    if name.lower() in [r.name for r in db.role_play_commands]:
        await edit_message(
            message,
            f"⚠ Такая РП-команда уже существует"
        )
        return
    
    db.role_play_commands.append(
        RolePlayCommand(
            name=name.lower(),
            gen=gen,
            formatter_man=formatter_man,
            formatter_woman=formatter_woman,
            all_ending=all_ending 
        )
    )
    db.save()
        
    await edit_message(
        message,
        f"✅ РП-команда «{name.lower()}» создана"
    )

@user.on.message_handler(FromMe(), text="<service_prefix:service_prefix> -мрп <name>",)
@logger_decorator
async def role_play_command_create_wrapper(
        message: Message,
        name: str,
        **kwargs
):
    db = Database.get_current()
    
    if name.lower() not in [r.name for r in db.role_play_commands]:
        await edit_message(
            message,
            f"⚠ РП-команды «{name.lower()}» не существует"
        )
        return
    
    rp = None
    for rp_ in db.role_play_commands:
        if rp_.name == name.lower():
            rp = rp_
            break
    
    db.role_play_commands.remove(rp)
    db.save()
        
    await edit_message(
        message,
        f"✅ РП-команда «{name.lower()}» удалена"
    )



import sys
import time
from typing import Callable, Union

from vkbottle import Message


class LoggerLevel:
    levels = {
        'debug': 0,
        'info': 1,
        "warning": 2,
        "warn": 2,
        "error": 3,
        "critical": 4,
        "crit": 4,
    }

    @staticmethod
    def get_int(level: Union[int, str]) -> int:
        if isinstance(level, int):
            return level

        return LoggerLevel.levels[level.lower()]

    @staticmethod
    def get_name(level: int) -> str:
        for key in LoggerLevel.levels.keys():
            if LoggerLevel.levels[key] == level:
                return key
        return "unknown"

    @staticmethod
    def get_cap_name(level: int) -> str:
        return LoggerLevel.get_name(level).upper()

    @staticmethod
    def get_short_name(level: int) -> str:
        return LoggerLevel.get_cap_name(level)[0]


class Logger(object):

    global_logger_level = 1

    def __init__(self, level: Union[int, str] = 1):
        self.logger_level = LoggerLevel.get_int(level)

    def __getattr__(self, item):
        if item in ["remove", "add", "level"]:
            return lambda *args, **kwargs: None

        if item in LoggerLevel.levels.keys():
            new_logger = Logger(LoggerLevel.get_int(item))
            new_logger.global_logger_level = self.global_logger_level
            return new_logger

        return super(Logger, self).__getattr__(item)

    def __call__(self, message: str, *args, **kwargs):
        if self.logger_level < self.global_logger_level:
            return

        output = sys.stdout if self.logger_level < 3 else sys.stderr
        t = time.strftime("%m-%d %H:%M:%S", time.localtime())

        try:
            message = str(message).format(*args, **kwargs)
        except:
            message = f"{message} {args} {kwargs}"

        output.write(
            f"\n[IDM LP] | {LoggerLevel.get_short_name(self.logger_level)} | "
            + message
            + f" [TIME {t}]"
        )


try:
    from loguru import logger
except ImportError:
    logger = Logger()


def logger_decorator(func: Callable) -> Callable:
    async def decorator(message: Message, *args, **kwargs):
        global logger
        try:
            start = time.time()
            result = await func(message, *args, **kwargs)
            delta = round(time.time() - start, 4)
            text = f"Message {message.id} ({message.peer_id}/{message.from_id}) " \
                   f"handled with function «{func.__name__}». " \
                   f"Text: «{message.text}». " \
                   f"Result: {result}. " \
                   f"Delta: {delta}"
            logger.info(text)
            return result
        except Exception as ex:
            text = f"Message {message.id} ({message.peer_id}/{message.from_id}) " \
                   f"handled with function «{func.__name__}». " \
                   f"Text: «{message.text}». " \
                   f"Error: {ex}."
            logger.error(text)

    return decorator



from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database
from idm_lp.utils import send_request

user = Blueprint(
    name='duty_signal_blueprint'
)


@user.on.message_handler(text='<prefix:duty_prefix> [id<user_id:int>|<name>] <signal>')
@logger_decorator
async def duty_signal(message: Message, prefix: str, user_id: int, signal: str, **kwargs):
    db = Database.get_current()
    if user_id != await message.api.user_id:
        return
    message_ = message.dict()
    __model = {
        "user_id": await message.api.user_id,
        "method": "lpSendSignal",
        "secret": db.secret_code,
        "message": {
            "conversation_message_id": message_['conversation_message_id'],
            "from_id": message_['from_id'],
            "date": message.date,
            "text": prefix + ' ' + signal,
            "peer_id": message.peer_id
        },
        "object": {
            "chat": None,
            "from_id": message_['from_id'],
            "value": prefix + ' ' + signal,
            "conversation_message_id": message_['conversation_message_id']
        },
        "vkmessage": message_
    }
    await send_request(__model)



from vkbottle.api import API

from idm_lp.database import Database


async def auto_infection_timer(api: API, db: Database):
    await api.messages.send(
        peer_id=db.auto_infection_peer_id,
        message=f"заразить {db.auto_infection_argument}",
        random_id=0,
    )



import re

from vkbottle.framework.framework.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database, RegexDeleter
from idm_lp.rules import RegexDeleter as RegexDeleterRule
from idm_lp.utils import edit_message

user = Blueprint(
    name='repeat_blueprint'
)


@user.on.message_handler(RegexDeleterRule())
@logger_decorator
async def repeat_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    for regex_del in db.regex_deleter:
        if regex_del.chat_id == message.peer_id:
            if re.findall(regex_del.regex, message.text):
                await message.api.messages.delete(message_ids=[message.id], delete_for_all=regex_del.for_all)


@user.on.message_handler(
    FromMe(),
    text=[
        '<prefix:service_prefix> +regex <name> <regex> <for_all:yes_or_no>',
        '<prefix:service_prefix> +regex <name> <regex>',
    ]
)
@logger_decorator
async def repeat_wrapper(message: Message, name: str, regex: str, for_all: bool = False, **kwargs):
    db = Database.get_current()

    if name in [regex_del.name for regex_del in db.regex_deleter]:
        await edit_message(message, "⚠ Такой шаблон удаления существует")
        return
    db.regex_deleter.append(RegexDeleter(name=name, regex=regex, for_all=for_all, chat_id=message.peer_id))
    db.save()
    await edit_message(message, "✅ Добавлено")


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> -regex <name>')
@logger_decorator
async def repeat_wrapper(message: Message,  name: str, **kwargs):
    db = Database.get_current()
    deleter = None
    for regex_del in db.regex_deleter:
        if regex_del.name == name:
            deleter = regex_del
    if deleter is None:
        await edit_message(message, "⚠ Такого шаблона удаления не существует")
        return
    db.regex_deleter.remove(deleter)
    db.save()
    await edit_message(message, "✅ Удалено")


@user.on.message_handler(FromMe(), text='<prefix:service_prefix> regex')
@logger_decorator
async def repeat_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    text = "📃 Шаблоны для удаления:\n"
    index = 1
    for regex_del in db.regex_deleter:
        text += f"{index}. {regex_del.name} | {regex_del.regex} | {regex_del.chat_id}\n"
        index += 1
    await edit_message(message, text)



import json

from apscheduler.schedulers.asyncio import AsyncIOScheduler


__version__ = '1.13.1'
__author__ = 'lordralinc'
__description__ = (
    "LP модуль позволяет работать приемнику сигналов «IDM multi» работать в любых чатах. "
    "Так же он добавляет игнор, глоигнор, мут и алиасы."
)

CONFIG_PATH = "config.json"
USE_APP_DATA = False

LOGGER_LEVEL = 'INFO'
VKBOTTLE_LOGGER_LEVEL = 'ERROR'
LOG_TO_PATH = False

BASE_DOMAIN = "https://idmduty.ru"


def CALLBACK_LINK():
    return f"{BASE_DOMAIN}/callback/"


def GET_LP_INFO_LINK():
    return f"{BASE_DOMAIN}/api/dutys/get_lp_info/"


GITHUB_LINK = "https://github.com/IDM-Team/idm_lp"
VERSION_REST = "https://raw.githubusercontent.com/IDM-Team/idm_lp/master/rest/version.json"
ALIASES_REST = "https://raw.githubusercontent.com/IDM-Team/idm_lp/master/rest/aliases.json"
ROLE_PLAY_COMMANDS_REST = "https://raw.githubusercontent.com/IDM-Team/idm_lp/master/rest/role_play_commands.json"

ENABLE_EVAL = False
ALLOW_SENTRY = True

try:
    with open('lp_dc_config.json', 'r', encoding='utf-8') as file:
        data = json.loads(file.read())
        APP_ID = data.get('app_id', 0)
        APP_SECRET = data.get('app_secret', "public")
except:
    APP_ID = 0
    APP_SECRET = "public"

APP_USER_AGENT = f"IDMLP({APP_ID};{APP_SECRET})"


scheduler = AsyncIOScheduler()



from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp import const
from idm_lp.database import Database
from idm_lp.logger import logger_decorator
from idm_lp.utils import edit_message

user = Blueprint(
    name='auto_infection_blueprint'
)


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> +автозаражение")
@logger_decorator
async def activate_auto_infection_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    db.auto_infection = True
    db.save(True)
    await edit_message(
        message,
        "✅ Автоматическое заражение включено"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> -автозаражение")
@logger_decorator
async def deactivate_auto_infection_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    db.auto_infection = False
    db.save(True)
    await edit_message(
        message,
        "✅ Автоматическое заражение выключено"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автозаражение интервал <int:interval>")
@logger_decorator
async def set_auto_infection_interval_wrapper(message: Message, interval: int, **kwargs):
    db = Database.get_current()
    if interval < 120:
        await edit_message(
            message,
            "⚠ Интервал автоматического заражения не может быть меньше 2х минут"
        )
        return

    db.auto_infection_interval = interval
    db.save(True)
    await edit_message(
        message,
        f"✅ Интервал автоматического заражения установлен на {interval} сек."
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автозаражение аргумент <argument>")
@logger_decorator
async def set_auto_infection_argument_wrapper(message: Message, argument: str, **kwargs):
    db = Database.get_current()
    db.auto_infection_argument = argument
    db.save(True)
    await edit_message(
        message,
        "✅ Аргумент автоматического заражения изменен"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автозаражение установить чат")
@logger_decorator
async def set_auto_infection_chat_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    db.auto_infection_peer_id = message.peer_id
    db.save(True)
    await edit_message(
        message,
        "✅ Чат автоматического заражения изменен"
    )


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автозаражение")
@logger_decorator
async def show_auto_infection_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    jobs = const.scheduler.get_jobs()
    next_run_time = None
    for job in jobs:
        if job.id == 'auto_infection_timer':
            next_run_time = job.next_run_time
    text = (
        f"☢ Состояние автоматического заражения:\n"
        f"{'Запущен' if db.auto_infection else 'Остановлен'}\n"
        f"⏱ Интервал заражения: {db.auto_infection_interval} сек.\n"
        f"🧨 Аргумент заражения: {db.auto_infection_argument}\n"
        f"💬 Чат заражения: {db.auto_infection_peer_id}\n\n"
    )
    if next_run_time:
        text += f'⏳ Следующий запуск: {next_run_time.strftime("%Y-%m-%d %H:%M:%S")}'
    await edit_message(message, text)



import argparse
import json
import traceback

import aiohttp
import requests
import vkbottle.api
from vkbottle.api import UserApi
from vkbottle.user import User

from idm_lp import const, timers
from idm_lp.commands import commands_bp
from idm_lp.database import Database, DatabaseError
from idm_lp.error_handlers import error_handlers_bp
from idm_lp.logger import logger, Logger, LoggerLevel
from idm_lp.utils import check_ping

parser = argparse.ArgumentParser(
    description='LP модуль позволяет работать приемнику сигналов «IDM multi» работать в любых чатах.\n'
                'Так же он добавляет игнор, глоигнор, мут и алиасы.'
)

parser.add_argument(
    '--config_path',
    type=str,
    dest="config_path",
    default="config.json",
    help='Путь до файла с конфингом'
)

parser.add_argument(
    '--base_domain',
    type=str,
    dest="base_domain",
    default="https://idmduty.ru",
    help='Базовый домен'
)

parser.add_argument(
    '--use_app_data',
    dest="use_app_data",
    action="store_const",
    const=True,
    help='Использовать папку AppData/IDM (Windows).\n'
         'При использовании этой настройки AppData/IDM и config_path складываются'
)

parser.add_argument(
    '--logger_level',
    dest="logger_level",
    type=str,
    default="INFO",
    help='Уровень логгирования.'
)

parser.add_argument(
    '--vkbottle_logger_level',
    dest="vkbottle_logger_level",
    type=str,
    default="ERROR",
    help='Уровень логгирования VKBottle.'
)

parser.add_argument(
    '--log_to_path',
    dest="log_to_path",
    action="store_const",
    const=True,
    help='Логи в файл'
)

parser.add_argument(
    '--enable_eval',
    dest="enable_eval",
    action="store_const",
    const=True,
    help='Разрешить eval/exec'
)


@Database.add_on_save
async def on_db_save(db: Database):
    api = vkbottle.api.API(tokens=db.tokens)
    const.scheduler.pause()
    const.scheduler.remove_all_jobs()
    if db.auto_infection:
        const.scheduler.add_job(
            timers.auto_infection_timer,
            id='auto_infection_timer',
            name='Таймер на авто заражение',
            args=(api, db,),
            trigger='interval',
            seconds=db.auto_infection_interval,
            max_instances=1
        )
        await timers.auto_infection_timer(api, db)
    const.scheduler.resume()


def lp_startup(database):
    async def _lp_startup():
        api = UserApi.get_current()
        db = Database.get_current()
        await on_db_save(db)
        text = f'IDM LP запущен\n' \
               f'Текущая версия: v{const.__version__}'
        version_rest = requests.get(const.VERSION_REST).json()

        if version_rest['version'] != const.__version__:
            text += f"\n\n Доступно обновление {version_rest['version']}\n" \
                    f"{version_rest['description']}\n" \
                    f"{const.GITHUB_LINK}"

        await api.messages.send(
            peer_id=await api.user_id,
            random_id=0,
            message=text
        )

        async with aiohttp.ClientSession(headers={"User-Agent": const.APP_USER_AGENT}) as session:
            async with session.post(const.GET_LP_INFO_LINK(), json={'access_token': database.tokens[0]}) as resp:
                response = await resp.json()
                if 'error' in response:
                    await api.messages.send(
                        peer_id=await api.user_id,
                        random_id=0,
                        message=f"⚠ Ошибка: {response['error']['detail']}"
                    )
                    raise KeyboardInterrupt()
                else:
                    if not response['response']['is_active']:
                        await api.messages.send(
                            peer_id=await api.user_id,
                            random_id=0,
                            message=f"⚠ Ошибка: дежурный не активен"
                        )
                        raise KeyboardInterrupt()
                    database.secret_code = response['response']['secret_code']
                    database.save()

        await check_ping(database.secret_code)

    return _lp_startup


def run_lp():
    args = parser.parse_args()

    const.CONFIG_PATH = args.config_path
    const.BASE_DOMAIN = args.base_domain
    const.USE_APP_DATA = args.use_app_data if args.use_app_data else False
    const.LOG_TO_PATH = args.log_to_path if args.log_to_path else False
    const.LOGGER_LEVEL = args.logger_level
    const.VKBOTTLE_LOGGER_LEVEL = args.vkbottle_logger_level
    const.ENABLE_EVAL = args.enable_eval if args.enable_eval else False

    if isinstance(logger, Logger):
        logger.global_logger_level = LoggerLevel.get_int(const.LOGGER_LEVEL)

    logger.warning(
        f"\n\nЗапуск с параметрами:\n"
        f" -> Уровень логгирования              -> {const.LOGGER_LEVEL}\n"
        f" -> Уровень логгирования VKBottle     -> {const.VKBOTTLE_LOGGER_LEVEL}\n"
        f" -> Логи в файл                       -> {const.LOG_TO_PATH}\n"
        f" -> Путь до файла с конфингом         -> {Database.get_path()}\n"
        f" -> Использовать папку AppData/IDM    -> {const.USE_APP_DATA}\n"
        f" -> Базовый домен                     -> {const.BASE_DOMAIN}\n"
        f" -> API                               -> {const.GET_LP_INFO_LINK()}\n"
        f" -> Callback link                     -> {const.CALLBACK_LINK()}\n"
        f" -> Разрешить eval/exec               -> {const.ENABLE_EVAL}\n\n"
    )

    try:
        db = Database.load()
        Database.set_current(db)
    except DatabaseError as ex:
        logger.error(
            f"{ex.name} | {ex.description}"
        )
        exit(-1)
    except json.JSONDecodeError as ex:
        logger.error(
            f'При запуске произошла ошибка базы данных.\n'
            f'Проверте целостность данных.\n'
            f'Строка: {ex.lineno}, столбец: {ex.colno}.'
        )
        exit(-1)

    except Exception as ex:
        logger.error(f'При запуске произошла ошибка [{ex.__class__.__name__}] {ex}\n{traceback.format_exc()}')
        exit(-1)
    else:
        from idm_lp.validators import (
            alias,
            role_play_command,
            self_prefix,
            duty_prefix,
            service_prefix,
            repeater_word,
            yes_or_no
        )

        user = User(
            tokens=db.tokens,
            debug=const.VKBOTTLE_LOGGER_LEVEL,
            log_to_path=const.LOG_TO_PATH
        )
        user.set_blueprints(
            *commands_bp,
            *error_handlers_bp,
        )
        const.scheduler.start()

        user.run_polling(
            auto_reload=False,
            on_startup=lp_startup(db),
        )



import asyncio
import json
import os
import typing
from typing import List

from pydantic import BaseModel, validator

from idm_lp import const
from . import (
    Alias,
    ChatEnterModel,
    IgnoredMembers,
    IgnoredGlobalMembers,
    MutedMembers,
    ContextInstanceMixin,
    RegexDeleter,
    RolePlayCommand,
    TrustedUser,
    SlouMo,
    DatabaseError
)


class Database(BaseModel, ContextInstanceMixin):
    secret_code: str = ""
    ru_captcha_key: str = ""
    repeater_word: str = ".."
    dd_prefix: str = "дд"

    auto_infection: bool = False
    auto_infection_interval: int = 3600
    auto_infection_peer_id: int = -174105461
    auto_infection_argument: str = "р"

    bio_reply: bool = False
    repeater_active: bool = False

    delete_all_notify: bool = False
    auto_exit_from_chat: bool = False
    auto_exit_from_chat_delete_chat: bool = False
    auto_exit_from_chat_add_to_black_list: bool = False
    disable_notifications: bool = False

    nometa_enable: bool = False
    nometa_message: str = "nometa.xyz"
    nometa_attachments: List[str] = []
    nometa_delay: float = 5 * 60

    tokens: List[str] = []
    service_prefixes: List[str] = [".слп", "!слп"]
    self_prefixes: List[str] = [".л", "!л"]
    duty_prefixes: List[str] = [".лд", "!лд"]

    ignored_members: List[IgnoredMembers] = []
    ignored_global_members: List[IgnoredGlobalMembers] = []
    muted_members: List[MutedMembers] = []
    aliases: List[Alias] = []
    role_play_commands: List[RolePlayCommand] = []
    trusted: List[TrustedUser] = []
    add_to_friends_on_chat_enter: List[ChatEnterModel] = []
    sloumo: List[SlouMo] = []
    regex_deleter: List[RegexDeleter] = []

    __on_save_listeners: typing.List[typing.Callable] = []

    def __enter__(self) -> "Database":
        return self

    def __exit__(self, exc_type, exc_val, exc_tb):
        self.save()

    @validator('tokens')
    def name_must_contain_space(cls, v):
        if not v:
            raise DatabaseError(
                name='Нет токенов',
                description='Укажите токены в файле конфигурации'
            )
        return v

    @staticmethod
    def get_path() -> str:
        if const.USE_APP_DATA:
            local_data_path = os.environ["APPDATA"]
            return os.path.abspath(
                os.path.join(
                    local_data_path,
                    "IDM",
                    const.CONFIG_PATH
                )
            )
        return os.path.abspath(const.CONFIG_PATH)

    @staticmethod
    def load() -> 'Database':
        path_to_file = Database.get_path()
        try:
            with open(path_to_file, 'r', encoding='utf-8') as file:
                db = Database(**json.loads(file.read()))
        except FileNotFoundError:
            db = None

        if not db:
            raise DatabaseError(
                'IDMLP не установлен',
                f"Для начала запустите процесс установки командой setup"
            )

        if not db.tokens:
            raise DatabaseError(
                'Нет токенов',
                f"Укажите токены в файле конфигурации по пути: {path_to_file}"
            )
        return db

    @classmethod
    def add_on_save(cls, func):
        cls.__on_save_listeners.append(func)
        return func

    def save(self, force_listeners: bool = False):
        path_to_file = Database.get_path()
        if force_listeners:
            for __on_save_listener in self.__on_save_listeners:
                asyncio.create_task(__on_save_listener(self))
        with open(path_to_file, 'w', encoding='utf-8') as file:
            file.write(
                self.json(exclude={'__on_save_listeners'}, **{"ensure_ascii": False, "indent": 2})
            )



from typing import Optional

from vkbottle.rule import FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database, Alias
from idm_lp.utils import send_request

user = Blueprint(
    name='aliases_blueprint'
)


async def send_signal(
        database: Database,
        message: Message,
        alias: Alias,
        separator: str = ' ',
        signal: Optional[str] = None
):
    message_ = message.dict()
    prepared_text = database.self_prefixes[0] + ' ' + alias.command_to
    prepared_text += f"{separator}{signal}" if signal else ''

    __model = {
        "user_id": message_['from_id'],
        "method": "lpSendMySignal",
        "secret": database.secret_code,
        "message": {
            "conversation_message_id": message_['conversation_message_id'],
            "from_id": message_['from_id'],
            "date": message.date,
            "text": prepared_text,
            "peer_id": message.peer_id
        },
        "object": {
            "chat": None,
            "from_id": message_['from_id'],
            "value": prepared_text,
            "conversation_message_id": message_['conversation_message_id']
        },
        "vkmessage": message_
    }

    await send_request(__model)


@user.on.message_handler(FromMe(), text=['<alias:alias> <signal>', '<alias:alias>'])
@logger_decorator
async def duty_signal(message: Message, alias: Alias, signal: str = None):
    db = Database.get_current()
    await send_signal(db, message, alias, ' ', signal)


@user.on.message_handler(FromMe(), text='<alias:alias>\n<signal>')
@logger_decorator
async def duty_signal_new_line(message: Message, alias: Alias, signal: str):
    db = Database.get_current()
    await send_signal(db, message, alias, '\n', signal)



from vkbottle.rule import ChatActionRule, FromMe
from vkbottle.user import Blueprint, Message

from idm_lp.logger import logger_decorator
from idm_lp.database import Database
from idm_lp.utils import edit_message

user = Blueprint(
    name='auto_exit_from_chat_blueprint'
)


async def set_auto_exit(
        db: Database,
        auto_exit: bool = None,
        delete_chat: bool = None,
        black_list: bool = None
):
    db.auto_exit_from_chat = auto_exit if auto_exit is not None else db.auto_exit_from_chat
    db.auto_exit_from_chat_delete_chat = delete_chat if delete_chat is not None else db.auto_exit_from_chat_delete_chat
    db.auto_exit_from_chat_add_to_black_list = (
        black_list if black_list is not None else db.auto_exit_from_chat_add_to_black_list
    )
    db.save()


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> +автовыход")
@logger_decorator
async def auto_exit_setting_on_exit_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await set_auto_exit(db, True, False)
    await edit_message(message, "&#9989; Настройка изменена")


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> -автовыход")
@logger_decorator
async def auto_exit_setting_on_exit_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await set_auto_exit(db, False, False)
    await edit_message(message, "&#9989; Настройка изменена")


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автовыход +чс")
@logger_decorator
async def auto_exit_setting_on_exit_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await set_auto_exit(db, black_list=True)
    await edit_message(message, "&#9989; Настройка изменена")


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автовыход -чс")
@logger_decorator
async def auto_exit_setting_on_exit_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await set_auto_exit(db, black_list=False)
    await edit_message(message, "&#9989; Настройка изменена")


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автовыход +удаление")
@logger_decorator
async def auto_exit_setting_on_exit_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await set_auto_exit(db, delete_chat=True)
    await edit_message(message, "&#9989; Настройка изменена")


@user.on.message_handler(FromMe(), text="<prefix:service_prefix> автовыход -удаление")
@logger_decorator
async def auto_exit_setting_on_exit_wrapper(message: Message, **kwargs):
    db = Database.get_current()
    await set_auto_exit(db, delete_chat=False)
    await edit_message(message, "&#9989; Настройка изменена")


@user.on.chat_message(ChatActionRule("chat_invite_user"))
@user.on.chat_message(ChatActionRule("chat_invite_user_by_link"))
@logger_decorator
async def to_chat_wrapper(message: Message):
    if message.action.member_id == await message.api.user_id:
        db = Database.get_current()
        if message.action.type == "chat_invite_user":
            if db.disable_notifications:
                await user.api.account.set_silence_mode(
                    time=-1,
                    peer_id=message.peer_id,
                    sound=0
                )
            if db.auto_exit_from_chat:
                await message.api.messages.remove_chat_user(chat_id=message.chat_id, member_id=await message.api.user_id)
            if db.auto_exit_from_chat_delete_chat:
                await message.api.messages.delete_conversation(peer_id=message.peer_id)
            if db.auto_exit_from_chat_add_to_black_list:
                await message.api.account.ban(owner_id=message.from_id)
        else:
            if db.disable_notifications:
                await user.api.account.set_silence_mode(
                    time=-1,
                    peer_id=message.peer_id,
                    sound=0
                )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['idm_lp',
 'idm_lp.commands',
 'idm_lp.commands.members_manager',
 'idm_lp.database',
 'idm_lp.error_handlers']

package_data = \
{'': ['*']}

install_requires = \
['APScheduler>=3.9.1,<4.0.0',
 'pydantic==1.7.3',
 'python-rucaptcha==3.0',
 'vkbottle==2.7.12']

setup_kwargs = {
    'name': 'idm-lp',
    'version': '1.13.1',
    'description': 'LP модуль позволяет работать приемнику сигналов «IDM multi» работать в любых чатах. Так же он добавляет игнор, глоигнор, мут и алиасы.',
    'long_description': '### IDM multi - LP module\n![PyPI](https://img.shields.io/pypi/v/idm-lp)\n![GitHub](https://img.shields.io/github/license/IDM-Team/idm_lp)\n![GitHub repo size](https://img.shields.io/github/repo-size/IDM-Team/idm_lp)\n[![Downloads](https://pepy.tech/badge/idm-lp)](https://pepy.tech/project/idm-lp)\n\nLP модуль позволяет работать приемнику сигналов «IDM multi» работать в любых чатах.\nТак же он добавляет игнор, глоигнор, мут и алиасы.\n\n<!--\n4: 252535322122234232\n  1  2  3  4  5\n1 a  b  c  d  e\n2 f  g  h  ij k\n3 l  m  n  o  p\n4 q  r  s  y  u\n5 v  w  x  y  z\n-->\n\n## Оглавление\n1. [Установка](#установка)\n2. [Аргументы запуска](#аргументы-запуска)\n3. [Структура конфигурационного файла config.json](#структура-кофигурационного-файла-configjson)\n4. [Команды модуля ЛП](#команды-модуля-лп)\n\n## Установка\n### Heroku \n_Инструкцию ~~любезно~~ предоставил [Юн Дэмин](https://vk.com/id616052556)_\n\n`<nick>` - ваш ник в гитхабе.<br>\n`<name>` - имя репозитория.\n\n1. Регистрируемся на [GitHub](https://github.com)\n2. Создаем закрытый репозиторий\n    ![](https://sun9-5.userapi.com/ZdunWUy0_UtICPscb8DDDXlKXrYpjY2GRHZK1Q/-tt19NoXdC4.jpg)\n3. Заходим в термукс или гит на ПК и пишем следующие команды:\n    ```shell script\n    git clone --bare https://github.com/lordralinc/idm_lp.git\n    cd idm_lp.git\n    git push --mirror https://github.com/<nick>/<name>.git\n    ```\n    _Может появится просьба войти в аккаунт, вводим логин и пароль от аккаунта и все готово_\n    ```shell script\n    cd ..\n    rm -rf idm_lp.git\n    ```\n4. Заходим на наш закрытый репозиторий и там где написано `2.0` изменяем на `master`.<br>\n5. Далее заходим в `config.json`, вставляем токен от Kate Mobile и секретный код IDM.\n6. Регистрируемся на [Heroku](https://heroku.com) и выбираем python.\n7. Переходим по ссылке: [dashboard.heroku.com/apps](https://dashboard.heroku.com/apps) и создаем приложение. \n    Выбираем европу и название приложение любое, чтоб угодить хероку.\n8. После создания мы окажемся в панели управления, нажимаем на GitHub и входим в аккаунт.\n    ![](https://sun9-47.userapi.com/pLLeZCAo1P4sQR1brlFdBwHtfBWhBQGfuILR-g/edHTCYYZ2CE.jpg)\n9. Нам нужно имя закрытого репозитория, вставляем и нажимаем `Search`, выбираем нужный нам репозиторий и нажимаем на `Connect`.\n10. Листаем вниз и видим кнопку `Deploy Branch`, рядом с кнопкой будет `2.0`, нажимаем и выбираем `master`, далее тыкаем на кнопку `Deploy Branch` и ждем.\n11. Вверху нажимаем на кнопку `Resources`.\n12. Нажимаем на карандашик слева, включаем и тыкаем на `Confirm`.\n13. Переходим обратно в `Deploy` и мотаем вниз делаем все как по пункту 10\n\n### Windows\n\nСкачиваем и устанавливаем:\n1. [Visual C++](https://support.microsoft.com/ru-ru/help/2977003/the-latest-supported-visual-c-downloads) (Если не установленно)\n2. [Python](https://www.python.org/ftp/python/3.7.7/python-3.7.7-amd64.exe)\n\nОткрываем CMD (Win + R и вводим cmd)\nВводим команды:\n```shell script\ncd путь_до_папки\npy -m venv env\nenv\\Scripts\\activate.bat\npy -m pip install -U idm_lp\npy -m idm_lp setup\n\nЗапуск:\ncd путь_до_папки\nenv\\Scripts\\activate.bat\ncd idm_lp\npy -m idm_lp \n```\n\n### Linux (Ubuntu 16.04 Server)\n```shell script\nsudo apt-get update -y\nsudo apt-get install build-essential tk-dev libncurses5-dev libncursesw5-dev libreadline6-dev libdb5.3-dev libgdbm-dev libsqlite3-dev libssl-dev libbz2-dev libexpat1-dev liblzma-dev zlib1g-dev libffi-dev -y\n\nwget https://www.python.org/ftp/python/3.7.7/Python-3.7.7.tar.xz\ntar xf Python-3.7.7.tar.xz\ncd Python-3.7.7\n./configure\nmake -j {число ядер} && sudo make altinstall\n```\n`{число ядер}` можно узнать командой `nproc`\n```shell script\ncd /root/\nsudo apt-get install git nano -y\n\npython3.7 -m venv env\n/root/env/bin/pip install idm_lp\n/root/env/bin/python3.7 -m idm_lp setup\n```\nСоздаем сервис для запуска\n```shell script\nnano /etc/systemd/system/idmlp.service\n```\nВводим\n```shell script\n[Unit]\nDescription=LP\nAfter=network.target\n\n[Service]\nUser=root\nGroup=www-data\nWorkingDirectory=/root/idm_lp\nExecStart=/root/env/bin/python3.7 -m idm_lp --config_path /root/idm_lp/config.json\n\n[Install]\nWantedBy=multi-user.target\n```\nНажимаем `ctrl + x` выходим\n```shell script\nsystemctl enable idmlp\nservice idmlp start\n```\n\n## Аргументы запуска \n- `--logger_level [DEBUG | INFO | WARNING | ERROR | CRITICAL]` — Уровень логгирования\n- `--config_path CONFIG_PATH` — Путь до файла с конфингом\n- `--use_app_data` — Использовать папку AppData/IDM (Windows). При использовании этой настройки AppData/IDM и config_path складываются\n- `--log_to_path` — Логи в файл\n- `--base_domain BASE_DOMAIN` — Базовый домен\n\n\n## Структура конфигурационного файла config.json\n\n- `tokens`            - Токены вк в количестве 3х штук. Получить можно [здесь](https://oauth.vk.com/authorize?client_id=2685278&scope=1073737727&redirect_uri=https://oauth.vk.com/blank.html&display=page&response_type=token&revoke=1)\n- `secret_code`       - Секретный код дежурного. Можно получить на странице настроек дежурного в графе `секретный код`\n- `service_prefixes`  - Префиксы для выполнения команд модуля ЛП (добавление в мутлист, создание алиасов и тд.)\n- `self_prefixes`     - Префиксы для высылки команд для себя (аналог !с .с ...)\n- `duty_prefixes`     - Префиксы для высылки команд для дежурного (аналог !д .д ...)\n\n**! Остальные поля заполняются программно**\n\n![](https://sun1-86.userapi.com/10hU2v5Z8sV0ZBeDGWtOn4alEdiYZy2qY4_Ajw/_BeWOFmtcdw.jpg "Пример заполнения config.json")\n\n## Команды модуля ЛП\n- `{сервисный префикс}` пинг/кинг/пиу — пинг\n- `{сервисный префикс}` инфо — информация о модуле ЛП\n***\n- `{сервисный префикс}` префиксы свои — просмотр своих префиксов\n- `{сервисный префикс}` префиксы дежурный — просмотр префиксов для дежурного\n- `{сервисный префикс}` +префикс `[свой/дежурный]` — создание префикса\n- `{сервисный префикс}` -префикс `[свой/дежурный]` — удаление префикса\n***\n- `{сервисный префикс}` алиасы - просмотр алиасов\n- `{сервисный префикс}` +алиас `{имя}` {enter} `{команда которую получает модуль ЛП}` {enter} `{команда которую отсылает модуль ЛП}`  — создание алиаса\n- `{сервисный префикс}` -алиас `{имя}` — удаление алиаса\n- `{сервисный префикс}` алиасы паки — просмотр паков алиасов\n- `{сервисный префикс}` алиасы пак `{имя пака}` — просмотр пака алиасов\n- `{сервисный префикс}` алиасы импорт `{имя пака}` — импорт пака алиасов\n***\n- `{сервисный префикс}` игнорлист — просмотр игнорлиста\n- `{сервисный префикс}` игнорлист все — просмотр игнорлиста по всем чатам\n- `{сервисный префикс}` +игнор `[{ссылка}/{упоминание}/{реплай}]` — добавить в игнорлист\n- `{сервисный префикс}` -игнор `[{ссылка}/{упоминание}/{реплай}]` — удалить из игнорлиста\n***\n- `{сервисный префикс}` глоигнорлист — просмотр глоигнорлиста\n- `{сервисный префикс}` +глоигнор `[{ссылка}/{упоминание}/{реплай}]` — добавить в глоигнорлист\n- `{сервисный префикс}` -глоигнор `[{ссылка}/{упоминание}/{реплай}]` — удалить из глоигнорлиста\n***\n- `{сервисный префикс}` мутлист — просмотр мутлиста\n- `{сервисный префикс}` мутлист все — просмотр мутлиста по всем чатам\n- `{сервисный префикс}` +мут `[{ссылка}/{упоминание}/{реплай}]` `{задержка}` — добавить в мутлист\n- `{сервисный префикс}` -мут `[{ссылка}/{упоминание}/{реплай}]` — удалить из мутлиста\n***\n- `{сервисный префикс}` довы — просмотр доверенных пользователей\n- `{сервисный префикс}` +дов `[{ссылка}/{упоминание}/{реплай}]` — добавить в дов-лист\n- `{сервисный префикс}` -дов `[{ссылка}/{упоминание}/{реплай}]` — удалить из дов-листа\n***\n- `{сервисный префикс}` regex — Просмотр шаблонов для удаления\n- `{сервисный префикс}` +regex `{имя}` `{regex}` `{для всех:да|нет}` — Добавить шаблон\n- `{сервисный префикс}` -regex `{имя}` — Удалить шаблон\n***\n- `{сервисный префикс}` +потворялка — включить повторялку\n- `{сервисный префикс}` -потворялка — выключить повторялку\n- `{триггер повторялки}``{сообщение}` — повторить сообщение\n***\n- `{сервисный префикс}` eval/exec `{script}` — выполнение скрипта\n***\n- `{сервисный префикс}` -уведы — модуль будет удалять упоминания типа `@all`, `@online`...\n- `{сервисный префикс}` +уведы — не будет удалять упоминания типа `@all`, `@online`...\n***\n- `{сервисный префикс}` рп — просмотр РП команд\n- `{сервисный префикс}` +мрп `{имя}` `{падеж}`\\n`{форматер для мужчин}`\\n`{форматер для женщин}`\\n`{окончание для всех}` — просмотр РП команд\n- `{сервисный префикс}` -мрп `{имя}` — просмотр РП команд\n***\n- `{сервисный префикс}` секретный код `{код}` — установка секретного кода\n- `{сервисный префикс}` токен каптчи `{токен}` — установка токена рукаптчи\n***\n- `{сервисный префикс}` +автовыход — включить автовыход из бесед в которые вас пригласили\n- `{сервисный префикс}` -автовыход — выключить автовыход из бесед в которые вас пригласили\n- `{сервисный префикс}` автовыход +удаление — удалять диалог при выходе\n- `{сервисный префикс}` автовыход -удаление — неудалять диалог при выходе\n- `{сервисный префикс}` автовыход +чс — включить добавление в ЧС пригласившего \n- `{сервисный префикс}` автовыход -чс — выключить добавление в ЧС пригласившего \n***\n- `{сервисный префикс}` +слоумо `{время}`\\n`{текст}` — установка слоумо режима\n- `{сервисный префикс}` -слоумо — удаление слоумо режима\n- `{сервисный префикс}` слоумо — просмотр настроек слоумо режима\n- `{сервисный префикс}` слоумо +белый список `{пользователь}` — добавление пользователя в белый список\n- `{сервисный префикс}` слоумо -белый список `{пользователь}` — удаление пользователя из белого списка\n- `{сервисный префикс}` слоумо время `{время}` — изменение времени задержки\n- `{сервисный префикс}` слоумо текст `{текст}` — изменение текста предупреждения\n***\n- `{сервисный префикс}` +добавление `{текст}` — включить отправку запросов в друзья, пользователям, которые заходят в чат. При этом будет отправляться приветственный `{текст}`.\n- `{сервисный префикс}` -добавление — отключить отправку запросов в друзья, пользователям, которые заходят в чат.\n***\n- `{сервисный префикс}` выключать уведы — включить выключение уведомлений при входе в беседу \n- `{сервисный префикс}` не выключать уведы — выключить выключение уведомлений при входе в беседу \n***\n- `{сервисный префикс}` +заражение — включить ответное заражение.\n- `{сервисный префикс}` -заражение — отключить ответное заражение.\n***\n- `{сервисный префикс}` +автозаражение — включить автоматическое.\n- `{сервисный префикс}` -автозаражение — отключить автоматическое.\n- `{сервисный префикс}` автозаражение интервал `{интервал}` — установить интервал автоматического заражения.\n- `{сервисный префикс}` автозаражение аргумент `{аргумент}` — установить аргумент автоматического заражения.\n- `{сервисный префикс}` автозаражение установить чат — установить чат автоматического заражения.\n- `{сервисный префикс}` автозаражение — информация об автоматическом заражении.\n***\n- `{сервисный префикс}` +nometa — включить nometa.\n- `{сервисный префикс}` -nometa — отключить nometa.\n- `{сервисный префикс}` nometa сообщение `{текст}` — изменить текст сообщения.\n- `{сервисный префикс}` nometa задержка `{задержка}` — изменить задержку.',
    'author': 'lordralinc',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://idmduty.ru',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
